@@ -191,7 +191,7 @@ mat bouncebyconstraint(vec x, vec lb, vec ub){
   
   for(unsigned int i = 0; i < toolow.size(); i++){
     if(toolow(i)){
-      if(is_finite(ub(i))){
+      if(std::isfinite(ub(i))){
         int k = ceil((lb(i) - x(i))/(2.0*(ub(i)-lb(i))));
         x(i) = x(i) + 2.0*(ub(i)-lb(i))*double(k);
         if(x(i) > ub(i)){
@@ -204,7 +204,7 @@ mat bouncebyconstraint(vec x, vec lb, vec ub){
       }
     }
     if(toohigh(i)){
-      if(is_finite(lb(i))){
+      if(std::isfinite(lb(i))){
         int k = ceil((lb(i) - x(i))/(2.0*(ub(i)-lb(i))));
         x(i) = x(i) + 2.0*(ub(i)-lb(i))*double(k);
         if(x(i) > ub(i)){
